<?php
function _changeUser(&$tof,$vars) {
	global $auth;
	$tof->setUser($vars['Owner']);
	$tof->initUser();
	$tof->render->updateUserInfo();
	$auth->auth['uid'] = $vars['Owner'];
}
?>